@@ -31,7 +31,7 @@ from meilisearch_fastapi.models.index import (
 router = APIRouter()
 
 
-@router.post("/", response_model=IndexInfo, status_code=201)
+@router.post("/", response_model=IndexInfo, status_code=201, tags=["MeiliSearch Index"])
 async def create_index(
     index_info: IndexBase, config: MeiliSearchConfig = Depends(get_config)
 ) -> IndexInfo:
@@ -46,7 +46,12 @@ async def create_index(
         )
 
 
-@router.delete("/filterable-attributes/{uid}", response_model=UpdateId, status_code=202)
+@router.delete(
+    "/filterable-attributes/{uid}",
+    response_model=UpdateId,
+    status_code=202,
+    tags=["MeiliSearch Index"],
+)
 async def delete_filterable_attributes(
     uid: str,
     config: MeiliSearchConfig = Depends(get_config),
@@ -57,7 +62,12 @@ async def delete_filterable_attributes(
         return await index.reset_filterable_attributes()
 
 
-@router.delete("/displayed-attributes/{uid}", response_model=UpdateId, status_code=202)
+@router.delete(
+    "/displayed-attributes/{uid}",
+    response_model=UpdateId,
+    status_code=202,
+    tags=["MeiliSearch Index"],
+)
 async def delete_displayed_attributes(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
@@ -67,7 +77,12 @@ async def delete_displayed_attributes(
         return await index.reset_displayed_attributes()
 
 
-@router.delete("/attributes/distinct/{uid}", response_model=UpdateId, status_code=202)
+@router.delete(
+    "/attributes/distinct/{uid}",
+    response_model=UpdateId,
+    status_code=202,
+    tags=["MeiliSearch Index"],
+)
 async def delete_distinct_attribute(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
@@ -77,7 +92,7 @@ async def delete_distinct_attribute(
         return await index.reset_distinct_attribute()
 
 
-@router.delete("/delete-if-exists/{uid}", status_code=204)
+@router.delete("/delete-if-exists/{uid}", status_code=204, tags=["MeiliSearch Index"])
 async def delete_if_exists(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> int:
     async with Client(config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
@@ -85,14 +100,16 @@ async def delete_if_exists(uid: str, config: MeiliSearchConfig = Depends(get_con
         return 204
 
 
-@router.delete("/{uid}", status_code=204)
+@router.delete("/{uid}", status_code=204, tags=["MeiliSearch Index"])
 async def delete_index(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> int:
     async with Client(config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
         return await index.delete()
 
 
-@router.delete("/ranking-rules/{uid}", response_model=UpdateId, status_code=202)
+@router.delete(
+    "/ranking-rules/{uid}", response_model=UpdateId, status_code=202, tags=["MeiliSearch Index"]
+)
 async def delete_ranking_rules(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
@@ -102,7 +119,12 @@ async def delete_ranking_rules(
         return await index.reset_ranking_rules()
 
 
-@router.delete("/searchable-attributes/{uid}", response_model=UpdateId, status_code=202)
+@router.delete(
+    "/searchable-attributes/{uid}",
+    response_model=UpdateId,
+    status_code=202,
+    tags=["MeiliSearch Index"],
+)
 async def delete_searchable_attributes(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
@@ -112,7 +134,12 @@ async def delete_searchable_attributes(
         return await index.reset_searchable_attributes()
 
 
-@router.delete("/sortable-attributes/{uid}", response_model=UpdateId, status_code=202)
+@router.delete(
+    "/sortable-attributes/{uid}",
+    response_model=UpdateId,
+    status_code=202,
+    tags=["MeiliSearch Index"],
+)
 async def delete_sortable_attributes(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
@@ -122,7 +149,9 @@ async def delete_sortable_attributes(
         return await index.reset_sortable_attributes()
 
 
-@router.delete("/stop-words/{uid}", response_model=UpdateId, status_code=202)
+@router.delete(
+    "/stop-words/{uid}", response_model=UpdateId, status_code=202, tags=["MeiliSearch Index"]
+)
 async def delete_stop_words(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> UpdateId:
     async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
@@ -130,7 +159,9 @@ async def delete_stop_words(uid: str, config: MeiliSearchConfig = Depends(get_co
         return await index.reset_stop_words()
 
 
-@router.delete("/synonyms/{uid}", response_model=UpdateId, status_code=202)
+@router.delete(
+    "/synonyms/{uid}", response_model=UpdateId, status_code=202, tags=["MeiliSearch Index"]
+)
 async def delete_synonyms(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> UpdateId:
     async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
@@ -138,7 +169,9 @@ async def delete_synonyms(uid: str, config: MeiliSearchConfig = Depends(get_conf
         return await index.reset_synonyms()
 
 
-@router.get("/filterable-attributes/{uid}", response_model=FilterableAttributes)
+@router.get(
+    "/filterable-attributes/{uid}", response_model=FilterableAttributes, tags=["MeiliSearch Index"]
+)
 async def get_filterable_attributes(
     uid: str,
     config: MeiliSearchConfig = Depends(get_config),
@@ -150,7 +183,9 @@ async def get_filterable_attributes(
         return FilterableAttributes(filterable_attributes=filterable_attributes)
 
 
-@router.get("/displayed-attributes/{uid}", response_model=DisplayedAttributes)
+@router.get(
+    "/displayed-attributes/{uid}", response_model=DisplayedAttributes, tags=["MeiliSearch Index"]
+)
 async def get_displayed_attributes(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> DisplayedAttributes:
@@ -161,7 +196,9 @@ async def get_displayed_attributes(
         return DisplayedAttributes(displayed_attributes=displayed_attributes)
 
 
-@router.get("/attributes/distinct/{uid}", response_model=DistinctAttribute)
+@router.get(
+    "/attributes/distinct/{uid}", response_model=DistinctAttribute, tags=["MeiliSearch Index"]
+)
 async def get_distinct_attribute(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> DistinctAttribute:
@@ -172,7 +209,7 @@ async def get_distinct_attribute(
         return DistinctAttribute(attribute=attribute)
 
 
-@router.get("/{uid}", response_model=IndexInfo)
+@router.get("/{uid}", response_model=IndexInfo, tags=["MeiliSearch Index"])
 async def get_index(
     uid: str,
     config: MeiliSearchConfig = Depends(get_config),
@@ -186,7 +223,7 @@ async def get_index(
         return index
 
 
-@router.get("/ranking-rules/{uid}", response_model=RankingRules)
+@router.get("/ranking-rules/{uid}", response_model=RankingRules, tags=["MeiliSearch Index"])
 async def get_ranking_rules(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> RankingRules:
@@ -197,7 +234,7 @@ async def get_ranking_rules(
         return RankingRules(ranking_rules=ranking_rules)
 
 
-@router.get("/stats/{uid}", response_model=IndexStats)
+@router.get("/stats/{uid}", response_model=IndexStats, tags=["MeiliSearch Index"])
 async def get_stats(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> IndexStats:
     async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
@@ -205,7 +242,7 @@ async def get_stats(uid: str, config: MeiliSearchConfig = Depends(get_config)) -
         return await index.get_stats()
 
 
-@router.get("/", response_model=List[IndexInfo])
+@router.get("/", response_model=List[IndexInfo], tags=["MeiliSearch Index"])
 async def get_indexes(
     config: MeiliSearchConfig = Depends(get_config),
 ) -> list[IndexInfo]:
@@ -218,7 +255,7 @@ async def get_indexes(
         return indexes
 
 
-@router.get("/primary-key/{uid}", response_model=PrimaryKey)
+@router.get("/primary-key/{uid}", response_model=PrimaryKey, tags=["MeiliSearch Index"])
 async def get_primary_key(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> PrimaryKey:
     async with Client(config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
@@ -227,7 +264,9 @@ async def get_primary_key(uid: str, config: MeiliSearchConfig = Depends(get_conf
         return PrimaryKey(primary_key=primary_key)
 
 
-@router.get("/searchable-attributes/{uid}", response_model=SearchableAttributes)
+@router.get(
+    "/searchable-attributes/{uid}", response_model=SearchableAttributes, tags=["MeiliSearch Index"]
+)
 async def get_searchable_attributes(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> SearchableAttributes:
@@ -238,7 +277,9 @@ async def get_searchable_attributes(
         return SearchableAttributes(searchable_attributes=attributes)
 
 
-@router.get("/sortable-attributes/{uid}", response_model=SortableAttributes)
+@router.get(
+    "/sortable-attributes/{uid}", response_model=SortableAttributes, tags=["MeiliSearch Index"]
+)
 async def get_sortable_attributes(
     uid: str, config: MeiliSearchConfig = Depends(get_config)
 ) -> SortableAttributes:
@@ -249,7 +290,7 @@ async def get_sortable_attributes(
         return SortableAttributes(sortable_attributes=attributes)
 
 
-@router.get("/stop-words/{uid}", response_model=StopWords)
+@router.get("/stop-words/{uid}", response_model=StopWords, tags=["MeiliSearch Index"])
 async def get_stop_words(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> StopWords:
     async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
@@ -258,7 +299,7 @@ async def get_stop_words(uid: str, config: MeiliSearchConfig = Depends(get_confi
         return StopWords(stop_words=stop_words)
 
 
-@router.get("/synonyms/{uid}", response_model=Synonyms)
+@router.get("/synonyms/{uid}", response_model=Synonyms, tags=["MeiliSearch Index"])
 async def get_synonyms(uid: str, config: MeiliSearchConfig = Depends(get_config)) -> Synonyms:
     async with Client(url=config.meilisearch_url, api_key=config.meilisearch_api_key) as client:
         index = client.index(uid)
@@ -267,7 +308,9 @@ async def get_synonyms(uid: str, config: MeiliSearchConfig = Depends(get_config)
         return Synonyms(synonyms=synonyms)
 
 
-@router.put("/filterable-attributes", response_model=UpdateId, status_code=202)
+@router.put(
+    "/filterable-attributes", response_model=UpdateId, status_code=202, tags=["MeiliSearch Index"]
+)
 async def update_filterable_attributes(
     filterable_attributes: FilterableAttributesWithUID,
     config: MeiliSearchConfig = Depends(get_config),
@@ -279,7 +322,9 @@ async def update_filterable_attributes(
         return await index.update_filterable_attributes(attributes)
 
 
-@router.put("/displayed-attributes", response_model=UpdateId, status_code=202)
+@router.put(
+    "/displayed-attributes", response_model=UpdateId, status_code=202, tags=["MeiliSearch Index"]
+)
 async def update_displayed_attributes(
     displayed_attributes: DisplayedAttributesUID, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
@@ -289,7 +334,9 @@ async def update_displayed_attributes(
         return await index.update_displayed_attributes(displayed_attributes.displayed_attributes)
 
 
-@router.put("/attributes/distinct", response_model=UpdateId, status_code=202)
+@router.put(
+    "/attributes/distinct", response_model=UpdateId, status_code=202, tags=["MeiliSearch Index"]
+)
 async def update_distinct_attribute(
     attribute_with_uid: DistinctAttributeWithUID, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
@@ -299,7 +346,7 @@ async def update_distinct_attribute(
         return await index.update_distinct_attribute(attribute_with_uid.attribute)
 
 
-@router.put("/", response_model=IndexInfo)
+@router.put("/", response_model=IndexInfo, tags=["MeiliSearch Index"])
 async def update_index(
     index_update: IndexUpdate, config: MeiliSearchConfig = Depends(get_config)
 ) -> IndexInfo:
@@ -314,7 +361,7 @@ async def update_index(
         return IndexInfo(**response.json())
 
 
-@router.put("/ranking-rules", response_model=UpdateId, status_code=202)
+@router.put("/ranking-rules", response_model=UpdateId, status_code=202, tags=["MeiliSearch Index"])
 async def update_ranking_rules(
     ranking_rules: RankingRulesWithUID, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
@@ -324,7 +371,9 @@ async def update_ranking_rules(
         return await index.update_ranking_rules(ranking_rules.ranking_rules)
 
 
-@router.put("/searchable-attributes", response_model=UpdateId, status_code=202)
+@router.put(
+    "/searchable-attributes", response_model=UpdateId, status_code=202, tags=["MeiliSearch Index"]
+)
 async def update_searchable_attributes(
     searchable_attributes: SearchableAttributesWithUID,
     config: MeiliSearchConfig = Depends(get_config),
@@ -335,7 +384,9 @@ async def update_searchable_attributes(
         return await index.update_searchable_attributes(searchable_attributes.searchable_attributes)
 
 
-@router.put("/sortable-attributes", response_model=UpdateId, status_code=202)
+@router.put(
+    "/sortable-attributes", response_model=UpdateId, status_code=202, tags=["MeiliSearch Index"]
+)
 async def update_sortable_attributes(
     sortable_attributes: SortableAttributesWithUID, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
@@ -345,7 +396,7 @@ async def update_sortable_attributes(
         return await index.update_sortable_attributes(sortable_attributes.sortable_attributes)
 
 
-@router.put("/stop-words", response_model=UpdateId, status_code=202)
+@router.put("/stop-words", response_model=UpdateId, status_code=202, tags=["MeiliSearch Index"])
 async def update_stop_words(
     stop_words: StopWordsWithUID, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
@@ -356,7 +407,7 @@ async def update_stop_words(
         return await index.update_stop_words(words)
 
 
-@router.put("/synonyms", response_model=UpdateId, status_code=202)
+@router.put("/synonyms", response_model=UpdateId, status_code=202, tags=["MeiliSearch Index"])
 async def update_synonyms(
     synonyms: SynonymsWithUID, config: MeiliSearchConfig = Depends(get_config)
 ) -> UpdateId:
